==> jc-1.4.0.tar.gz: javax/swing/LayoutFocusTraversalPolicy__24LayoutComparator.h <==
// class javax.swing.LayoutFocusTraversalPolicy$LayoutComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 71c0e16ab1f1ab3e javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_
#define _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object;

typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype;

// Constructors
extern void _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *);

// Virtual methods
extern jint _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
};

// Vtype
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype {
	_jc_type			type;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs {
    _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
};

// Object instance structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object {
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype	*vtype;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$class_object;

#endif	/* _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_ */

==> jc-1.4.6.tar.gz: javax/swing/LayoutFocusTraversalPolicy__24LayoutComparator.h <==
// class javax.swing.LayoutFocusTraversalPolicy$LayoutComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 71c0e16ab1f1ab3e javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_
#define _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs;
typedef struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object;

typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable;
typedef const struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype;

// Constructors
extern void _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vmethods	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
};

// Vtype
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype {
	_jc_type			type;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs {
    _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_refs	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$sub_nonrefs	javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator;
};

// Object instance structure
struct _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$object {
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype	*vtype;
	_jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$vtype _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator$class_object;

#endif	/* _JC_javax_swing_LayoutFocusTraversalPolicy__24LayoutComparator_H_ */
